============
Installation
============

At the command line::

    $ easy_install eventbrite

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv eventbrite
    $ pip install eventbrite
